@@ -283,6 +283,9 @@ SERVICE_VERSIONS = {
     "ie": [
         "2020-03-04"
     ],
+    "iecp": [
+        "2021-09-14"
+    ],
     "iir": [
         "2020-04-17"
     ],
